"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_simple_ast_1 = require("ts-simple-ast");
var lodash_1 = require("lodash");
function getAst(tsConfigPath, sourceFilesPaths) {
    var ast = new ts_simple_ast_1.default({
        tsConfigFilePath: tsConfigPath,
        addFilesFromTsConfig: !Array.isArray(sourceFilesPaths)
    });
    if (sourceFilesPaths) {
        ast.addExistingSourceFiles(sourceFilesPaths);
    }
    return ast;
}
exports.getAst = getAst;
function parseClasses(classDeclaration) {
    var className = classDeclaration.getName();
    var propertyDeclarations = classDeclaration.getProperties();
    var methodDeclarations = classDeclaration.getMethods();
    var properties = propertyDeclarations.map(function (property) {
        var sym = property.getSymbol();
        if (sym) {
            return {
                name: sym.getName()
            };
        }
    }).filter(function (p) { return p !== undefined; });
    var methods = methodDeclarations.map(function (method) {
        var sym = method.getSymbol();
        if (sym) {
            return {
                name: sym.getName()
            };
        }
    }).filter(function (p) { return p !== undefined; });
    return { className: className, properties: properties, methods: methods };
}
exports.parseClasses = parseClasses;
function parseInterfaces(interfaceDeclaration) {
    var interfaceName = interfaceDeclaration.getName();
    var propertyDeclarations = interfaceDeclaration.getProperties();
    var methodDeclarations = interfaceDeclaration.getMethods();
    var properties = propertyDeclarations.map(function (property) {
        var sym = property.getSymbol();
        if (sym) {
            return {
                name: sym.getName()
            };
        }
    }).filter(function (p) { return p !== undefined; });
    var methods = methodDeclarations.map(function (method) {
        var sym = method.getSymbol();
        if (sym) {
            return {
                name: sym.getName()
            };
        }
    }).filter(function (p) { return p !== undefined; });
    return { interfaceName: interfaceName, properties: properties, methods: methods };
}
exports.parseInterfaces = parseInterfaces;
function parseHeritageClauses(classDeclaration) {
    var className = classDeclaration.getName();
    var heritageClauses = classDeclaration.getHeritageClauses();
    var implementsClauses = heritageClauses.map(function (heritageClause) {
        return lodash_1.flatten(heritageClause
            .getChildren()
            .map(function (ff) { return ff.getChildren().map(function (c) { return c.getText(); }); }));
    });
    var result = lodash_1.flatten(implementsClauses).map(function (clause) { return ({ clause: clause, className: className }); });
    return result;
}
exports.parseHeritageClauses = parseHeritageClauses;
